@@ -11,6 +11,10 @@ export DIB_ELEMENTS=$(python -c '
 import diskimage_builder.paths
 diskimage_builder.paths.show_path("elements")')
 
+# XXX: This will move into the gate scripts, and happen before
+# we run this script ... just here for initial bringup
+./openstack/diskimage-builder/contrib/setup-gate-mirrors.sh
+
 # Setup sane locale defaults, because this information is leaked into DIB.
 export LANG=en_US.utf8
 export LC_ALL=
@@ -36,7 +40,12 @@ DEFAULT_SKIP_TESTS=(
     # in testing does not work always.
     debian-minimal/testing-build-succeeds
     # No longer reasonable to test upstream (lacks a mirror in infra)
+    # note this is centos6
     centos/build-succeeds
+    # Needs infra mirroring to be stable
+    debian-minimal/stable-build-succeeds
+    debian-minimal/stable-vm
+    debian/build-succeeds
 )
 
 # The default output formats (specified to disk-image-create's "-t"
